@@ -84,7 +84,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
